#
#  _____ _______       _____                  _____                  _____      _             __               
# |  __ (_)  _  \  _  |  _  |                /  ___|                |_   _|    | |           / _|              
# | |  \/_| | | |_| |_| | | |_ __   ___ _ __ \ `--.  ___  ___  ___    | | _ __ | |_ ___ _ __| |_ __ _  ___ ___ 
# | | __| | | | |_   _| | | | '_ \ / _ \ '_ \ `--. \/ _ \/ _ \/ __|   | || '_ \| __/ _ \ '__|  _/ _` |/ __/ _ \
# | |_\ \ | |/ /  |_| \ \_/ / |_) |  __/ | | /\__/ /  __/  __/\__ \  _| || | | | ||  __/ |  | || (_| | (_|  __/
#  \____/_|___/        \___/| .__/ \___|_| |_\____/ \___|\___||___/  \___/_| |_|\__\___|_|  |_| \__,_|\___\___|
#                           | |                                                                                
#                           |_|                                                                                
#
# GiD + OpenSees Interface - An Integrated FEA Platform
# Copyright (C) 2016-2017
#
# Lab of R/C and Masonry Structures
# School of Civil Engineering, AUTh
#  
# Development team
#
# T. Kartalis-Kaounis, Civil Engineer AUTh
# V. Protopapadakis, Civil Engineer AUTh
# T. Papadopoulos, Civil Engineer AUTh
# 
# Project coordinator
#
# V.K. Papanikolaou, Assistant Professor AUTh
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# --------------------------------------------------------------------------------------------------------------
#
# OPENSEES MODEL DATA FILE (Two dimensional / Three degrees of freedom)
#
# --------------------------------------------------------------------------------------------------------------

# Modeling environment (ndm = model dimensions, ndf = global degrees of freedom)

model BasicBuilder -ndm 2 -ndf 3

# --------------------------------------------------------------------------------------------------------------
# N O D E S
# --------------------------------------------------------------------------------------------------------------

# node $NodeTag $XCoord $Ycoord

node      1    3.000    0.000 
node      2    3.000    0.500 
node      3    3.000    1.000 
node      4    3.000    1.500 
node      5    3.000    2.000 
node      6    3.000    2.500 
node      7    3.000    3.000 
node      8    0.000    0.000 
node      9    2.500    3.000 
node     10    0.000    0.500 
node     11    0.000    1.000 
node     12    2.000    3.000 
node     13    1.500    3.000 
node     14    0.000    1.500 
node     15    3.000    3.500 
node     16    1.000    3.000 
node     17    0.000    2.000 
node     18    0.500    3.000 
node     19    0.000    2.500 
node     20    3.000    4.000 
node     21    0.000    3.000 
node     22    3.000    4.500 
node     23    0.000    3.500 
node     24    0.000    4.000 
node     25    3.000    5.000 
node     26    0.000    4.500 
node     27    3.000    5.500 
node     28    0.000    5.000 
node     29    3.000    6.000 
node     30    2.500    6.000 
node     31    2.000    6.000 
node     32    1.500    6.000 
node     33    0.000    5.500 
node     34    1.000    6.000 
node     35    3.000    6.500 
node     36    0.500    6.000 
node     37    0.000    6.000 
node     38    3.000    7.000 
node     39    0.000    6.500 
node     40    3.000    7.500 
node     41    0.000    7.000 
node     42    3.000    8.000 
node     43    0.000    7.500 
node     44    3.000    8.500 
node     45    0.000    8.000 
node     46    3.000    9.000 
node     47    0.000    8.500 
node     48    2.500    9.000 
node     49    2.000    9.000 
node     50    1.500    9.000 
node     51    1.000    9.000 
node     52    0.500    9.000 
node     53    0.000    9.000 

# --------------------------------------------------------------------------------------------------------------
# C O N S T R A I N T S
# --------------------------------------------------------------------------------------------------------------

# Body Constraint/equalDOF Definition : equalDOF $MasterNode $SlaveNode $DOFs

equalDOF      7     21   1
equalDOF     29     37   1
equalDOF     46     53   1

# --------------------------------------------------------------------------------------------------------------
# M A S S E S
# --------------------------------------------------------------------------------------------------------------

# Mass Definition : mass $NodeTag $(ndf nodal mass values corresponding to each DOF)

mass      7   10.000    0.000    0.000
mass     21   10.000    0.000    0.000
mass     29   10.000    0.000    0.000
mass     37   10.000    0.000    0.000
mass     46   10.000    0.000    0.000
mass     53   10.000    0.000    0.000

# --------------------------------------------------------------------------------------------------------------
# R E S T R A I N T S
# --------------------------------------------------------------------------------------------------------------

# fix $NodeTag x-transl y-transl z-rot 

fix      1   1   1   1
fix      8   1   1   1

# fix of unused DOFs for stdBrick nodes


# --------------------------------------------------------------------------------------------------------------
# E L A S T I C   B E A M - C O L U M N   E L E M E N T S
# --------------------------------------------------------------------------------------------------------------

# Geometric Transformation

geomTransf Linear 1 
geomTransf PDelta 2

# Elastic Beam Column Definition
 
# element elasticBeamColumn $eleTag $iNode $jNode $A $E $Iz $transfTag <-mass $MassPerUnitLength>

element elasticBeamColumn      1      8    10   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn      2     10    11   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn      3     11    14   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn      4     14    17   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn      5     17    19   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn      6     19    21   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn      7     21    23   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn      8     23    24   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn      9     24    26   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     10     26    28   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     11     28    33   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     12     33    37   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     13     37    36   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     14     36    34   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     15     34    32   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     16     32    31   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     17     31    30   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     18     30    29   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     19     29    27   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     20     27    25   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     21     25    22   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     22     22    20   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     23     20    15   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     24     15     7   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     25      7     6   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     26      6     5   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     27      5     4   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     28      4     3   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     29      3     2   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     30      2     1   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     31     21    18   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     32     18    16   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     33     16    13   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     34     13    12   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     35     12     9   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     36      9     7   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     37     37    39   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     38     39    41   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     39     41    43   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     40     43    45   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     41     45    47   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     42     47    53   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     43     53    52   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     44     52    51   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     45     51    50   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     46     50    49   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     47     49    48   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     48     48    46   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     49     46    44   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     50     44    42   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     51     42    40   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     52     40    38   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     53     38    35   0.250000   33000000   0.005208    1   -mass    0.000
element elasticBeamColumn     54     35    29   0.250000   33000000   0.005208    1   -mass    0.000

# --------------------------------------------------------------------------------------------------------------
# R E C O R D E R S
# --------------------------------------------------------------------------------------------------------------

recorder Element -file ElasticBeamColumn_localForce.out -time -ele 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 localForce
recorder Node -file Node_displacements.out -time -nodeRange 1 53 -dof 1 2 6 disp
recorder Node -file Node_reactions.out -time -nodeRange 1 53 -dof 1 2 6 reaction

logFile log.txt

# --------------------------------------------------------------------------------------------------------------

set time_start [clock seconds]
puts "\nAnalysis started  : [clock format $time_start -format %H:%M:%S]"
puts ""

# --------------------------------------------------------------------------------------------------------------
#
# I N T E R V A L   1
#
# --------------------------------------------------------------------------------------------------------------

puts "Interval 1"
puts ""

# Loads

pattern Plain 100 Linear {
  load     21  100.000    0.000    0.000
  load     37  100.000    0.000    0.000
  load     53  100.000    0.000    0.000
}

# Perform eigenvalue analysis

set numModes 3

# Record eigenvectors

for { set k 1 } { $k <= $numModes } { incr k } {
  recorder Node -file [format "Mode_%i.out" $k] -nodeRange 1 53 -dof 1 2 6  "eigen $k" 
}

set lambda [eigen -fullGenLapack $numModes];

# Calculate periods

set T {}
foreach lam $lambda {
  lappend T [expr 6.283185/sqrt($lam)]
}

# Write periods file

set period "Periods.out"
set Periods [open $period "w"]
foreach t $T {
  puts $Periods "$t"
}
close $Periods

# Analysis options

system BandGeneral
numberer RCM
constraints Transformation
integrator LoadControl 1 
algorithm Linear 
analysis Static
analyze 1

# --------------------------------------------------------------------------------------------------------------

set time_end [clock seconds]
set analysisTime [expr $time_end-$time_start]
puts "Analysis finished : [clock format $time_end -format %H:%M:%S]"
puts "Analysis time     : $analysisTime seconds"
puts "\nAnalysis finished."

# --------------------------------------------------------------------------------------------------------------
#
# M E T A D A T A
#
# --------------------------------------------------------------------------------------------------------------

# Number of nodes
# 53

# Elements 1D

# 54

# Elements 2D
# 0

# Elements 3D
# 0

# ElasticBeamColumn
# 54
# 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 

# ----------------------------------------------------------------------------------------------------------------------------------------
#
# F R A M E   L O C A L   A X E S   O R I E N T A T I O N
#
# ----------------------------------------------------------------------------------------------------------------------------------------
#
#      ID                           Type                    Local-x                    Local-y                    Local-z          Literal
#
#       1              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#       2              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#       3              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#       4              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#       5              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#       6              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#       7              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#       8              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#       9              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#      10              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#      11              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#      12              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#      13              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      14              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      15              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      16              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      17              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      18              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      19              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      20              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      21              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      22              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      23              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      24              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      25              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      26              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      27              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      28              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      29              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      30              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      31              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      32              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      33              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      34              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      35              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      36              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      37              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#      38              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#      39              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#      40              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#      41              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#      42              ElasticBeamColumn     {+0.000 +1.000 +0.000}     {-1.000 +0.000 +0.000}     {+0.000 -0.000 +1.000}     { +Y -X +Z }
#      43              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      44              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      45              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      46              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      47              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      48              ElasticBeamColumn     {+1.000 +0.000 +0.000}     {+0.000 +1.000 +0.000}     {+0.000 +0.000 +1.000}     { +X +Y +Z }
#      49              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      50              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      51              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      52              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      53              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
#      54              ElasticBeamColumn     {+0.000 -1.000 +0.000}     {+1.000 +0.000 -0.000}     {+0.000 +0.000 +1.000}     { -Y +X +Z }
